@@ -138,7 +138,7 @@ fim.saemix<-function(saemixObject) {
     # Invert avoiding numerical problems
     Gi[[i]]<-round(Vi*1e10)/1e10
     VD<-try(eigen(Gi[[i]]))
-    if(class(VD)=="try-error") {
+    if(is(VD,"try-error")) {
       cat("Unable to compute the FIM by linearisation.\n")
       stop()
       #    return(saemixObject)
@@ -248,7 +248,7 @@ fim.saemix<-function(saemixObject) {
     #   indMF[[i]][1:npar,1:npar]<-Fmui
     # }
     Cth<-try(solve(Fth))
-    if(class(Cth)=="try-error") {
+    if(is(Cth,"try-error")) {
       cat("Error computing the Fisher Information Matrix: singular system.\n")
       Cth<-NA*Fth
     }
@@ -265,7 +265,7 @@ fim.saemix<-function(saemixObject) {
   
   FO<-MF[-c(1:npar),-c(1:npar)]
   CO<-try(solve(FO))
-  if(class(CO)=="try-error") {
+  if(is(CO,"try-error")) {
     CO<-NA*FO
     cat("Error computing the Fisher Information Matrix: singular system.\n")
   }
